@@ -8,7 +8,7 @@ define('INGO_BLACKLIST_MARKER', '++DELETE++');
 /**
  * Ingo base class.
  *
- * $Horde: ingo/lib/Ingo.php,v 1.69.6.18 2008/04/17 14:46:41 chuck Exp $
+ * $Horde: ingo/lib/Ingo.php,v 1.69.6.21 2008/09/01 12:05:25 jan Exp $
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -56,7 +56,7 @@ class Ingo {
                     $text .= '"';
                 }
                 $text .= ">\n";
-                $text .= '<option value="">' . _("Select target folder") . "</option>\n";
+                $text .= '<option disabled="disabled" value="">' . _("Select target folder") . "</option>\n";
 
                 if ($registry->hasMethod('mail/createFolder')) {
                     $text .= '<option value="">' . _("Create new folder") . "</option>\n";
@@ -66,9 +66,12 @@ class Ingo {
 
                 foreach ($mailboxes as $mbox) {
                     $sel = ($mbox['val'] && ($mbox['val'] === $value)) ? ' selected="selected"' : '';
+                    $disabled = empty($mbox['val']) ? ' disabled="disabled"' : '';
                     $val = htmlspecialchars($mbox['val']);
                     $label = $mbox['abbrev'];
-                    $text .= sprintf('<option value="%s"%s>%s</option>%s', $val, $sel, Text::htmlSpaces($label), "\n");
+                    $text .= sprintf('<option%s value="%s"%s>%s</option>%s',
+                                     $disabled, $val, $sel,
+                                     Text::htmlSpaces($label), "\n");
                 }
 
                 $text .= '</select>';
@@ -392,7 +395,9 @@ class Ingo {
         if (in_array(INGO_STORAGE_ACTION_SPAM, $_SESSION['ingo']['script_categories'])) {
             $menu->add(Horde::applicationUrl('spam.php'), _("S_pam"), 'spam.png');
         }
-        if ($_SESSION['ingo']['script_generate']) {
+        if ($_SESSION['ingo']['script_generate'] &&
+            (!$GLOBALS['prefs']->isLocked('auto_update') ||
+             !$GLOBALS['prefs']->getValue('auto_update'))) {
             $menu->add(Horde::applicationUrl('script.php'), _("_Script"), 'script.png');
         }
         if (!empty($GLOBALS['ingo_shares']) && empty($GLOBALS['conf']['share']['no_sharing'])) {
